<?php

/**
 * Implementiert die beroCloud und SNMP Einstellungen
 * @author Miguel Palmer <mp@beronet.com>
 */

include_once('/usr/www/include/SQLite2ToSQLite3.php');

class RemoteManagement {

	private		$m_attr;

	private		$post_attr,
			$post_checked = 0;

	private 	$isRequestRejected = 0,
			$reasonRejected = array();

	function __construct($m, $get = array(), $post = array(), $session = array()) {
		$this->m_attr = $m;

		// TODO: maybe set a checkor for an user input instead the 'config-option' checkor
		if (isset($post['submit'])) {
			unset($post['m'], $post['fixChrome'], $post['dummy'], $post['submit']);

			$list_post = array(
						// SNMP
						'snmp_enabled' => 'bool', 'snmptraps' => 'select', 'snmp_syslocation' => 'hostname', 'snmptraps_sink' => 'config-option', 'snmptraps_intervall' => 'int>=0',
						'snmp_community_rw' => 'snmp', 'snmp_community_ro' => 'snmp', 'snmp_community_trap' => 'snmp',
			);
		
			$list_post_options = array(	
							'snmptraps' => array('snmptrap_isdnl2'),
						  );

			$this->post_checked = 1;
			$this->post_attr = Helper::sanitizePost($post, $list_post, $this->post_checked, $this->reasonRejected, $list_post_options);

			$this->isRequestRejected = !$this->post_checked;
		}
	}

	/*
	 * @return string HTML code
	 */
	function _display_tabs ($ba) {
		$tabs = "\t\t".'<li><a href="#tabs-1">'. SNMP_TABLE_HEADER_DIS .'</a></li>' . "\n";
		$display_tabs = $this -> _display_tab1() . "\n";

		$html_str = '<br/>' . "\n" . '<br/>' . "\n" .
								'<script>' . "\n" .
								"\t" . '$(function() {' . "\n" .
								"\t\t" . '$( "#tabs" ).tabs({active:0})' . "\n" .
								"\t" . '});' . "\n" . 
								'</script>' . "\n" .
								"\n\n" . '<!-- BEGIN TABS //-->' . "\n\n" .
								'<div id="tabs" class="">' . "\n" .
								"\t".'<ul>' . "\n" .
								$tabs .
								"\t".'</ul>' . "\n\n" .
								$display_tabs . 
								"\n\n" . '<!-- END TABS //-->' . "\n" .
								'</div>' . "\n\n";

		return $html_str;
	}

	/*
	 * @return string HTML code
	 */
	function _display_tab1 () {
		$html_str = "\n\n" . '<!-- BEGIN TAB4 //-->' . "\n\n" .
								'<div id="tabs-4" style="margin-top: 20px;">' . "\n";

		$html_str .= $this->snmpTable() ."\n" .
								 "<br>\n" .
								 "<div class='text-center'>\n" .
								 "\t<i>" . REQUIRED_FIELDS . "</i>\n" . 
								 "</div>\n";

		$html_str .= '</div>' . "\n";

		return $html_str;
	}

	/**
	 * Generiert die HTML Seite
	 * @return string HTML code
	 */
	function display() {
		$m = $this->m_attr;
		$name = "REMOTE_MANAGEMENT_TITLE_DIS";
		include('./includes/header.php');

		$ba = new beroAri();
		require_once( '/usr/fallback/beroConf.php' );
		require_once("./includes/lang.php");
		//Save the changes
		if ($this->post_checked) {
			$ret .= $this->save($ba);
		} else if ($this->isRequestRejected) {
			$ret .= Helper::displayErrorMessage($this->reasonRejected['request'], $this->reasonRejected['checkor'], $this->reasonRejected['key']);
		}

		$ret .= $this -> _display_tabs($ba);
		$ret .= $this -> javascript();

		return $ret;
	}

	/**
	 * @return string Checkbox Enable SNMP
	 */
	function snmp_enabled() {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
		$snmp_enable = $bc->get("root", "snmp-enabled");
		$checked = ($snmp_enable == "1") ? "checked" : "";
		ob_start();
		?>
		<input type='hidden' name='snmp_enabled' value='0'>
		<input type='checkbox' id='snmp_enable' onchange='snmp_show();' name='snmp_enabled' value='1' <?php echo $checked ?>>
		<?php
		return ob_get_clean();
	}

	/**
	 * @return string Textfeld SNMP Syslocation
	 */
	function snmp_syslocation() {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
		$snmp_syslocation = $bc->get('root', 'snmp-syslocation');
		ob_start();
		?>
		<input type="text" class="form-control input-sm" name="snmp_syslocation" value="<?php echo $snmp_syslocation ?>" maxlength="255" >
		<?php
		return ob_get_clean();
	}

	/**
	 * @return string Checkbox Enable SNMP traps
	 */
	function snmptraps() {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
		$snmptraps = $bc->get("root", "snmptraps");
		$snmptraps = explode(",", $snmptraps);
		$checked = (in_array("snmptrap_isdnl2", $snmptraps)) ? "checked" : "";
		ob_start();
		?>
		<input type='checkbox' name='snmptraps' value='snmptrap_isdnl2' <?php echo $checked ?>> ISDN-Layer 2
		<?php
		return ob_get_clean();
	}

	/**
	 * @return string Textfeld SNMP traps sink
	 */
	function snmptraps_sink() {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
		$snmptraps_sink = $bc->get("root", "snmptraps_sink");
		ob_start();
		?>
		<input type='text' class='form-control input-sm' name='snmptraps_sink' value='<?php echo $snmptraps_sink ?>'>
		<?php
		return ob_get_clean();
	}

	/**
	 * @return string Textfeld SNMP traps intervall
	 */
	function snmptraps_intervall() {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
		$snmptraps_intervall = $bc->get("root", "snmptraps_intervall");
		ob_start();
		?>
		<input type='text' class='form-control input-sm' name='snmptraps_intervall' value='<?php echo $snmptraps_intervall ?>'>
		<?php
		return ob_get_clean();
	}

	/**
	 * @return string Textfeld SNMP community ro
	 */
	function ro_community() {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
		$ro_community = $bc->get("root", "snmp-community-ro");
		ob_start();
		?>
		<input type='text' class='form-control input-sm' name='snmp_community_ro' value='<?php echo $ro_community ?>'>
		<?php
		return ob_get_clean();
	}

	/**
	 * @return string Textfeld SNMP community rw
	 */
	function rw_community() {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
		$rw_community = $bc->get("root", "snmp-community-rw");
		ob_start();
		?>
		<input type='text' class='form-control input-sm' name='snmp_community_rw' value='<?php echo $rw_community ?>'>
		<?php
		return ob_get_clean();
	}

	/**
	 * @return string Textfeld SNMP community trap
	 */
	function community_trap() {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
		$community_trap = $bc->get("root", "snmp-community-trap");
		ob_start();
		?>
		<input type='text' class='form-control input-sm' name='snmp_community_trap' value='<?php echo $community_trap ?>'>
		<?php
		return ob_get_clean();
	}

	/**
	 * Generates the javascript code
	 * @return string
	 */
	function javascript() {
		ob_start();
		?>
		<script type="text/javascript">
		    $(document).ready(function () {
		        snmp_show();
		    });
		    function snmp_show() {
		        if ($('#snmp_enable').is(':checked')) {
		            $('#traps').show();
		            $('#sink').show();
		            $('#interval').show();
		            $('#communityRo').show();
		            $('#communityRw').show();
		            $('#communityTrap').show();
		        } else {
		            $('#traps').hide();
		            $('#sink').hide();
		            $('#interval').hide();
		            $('#communityRo').hide();
		            $('#communityRw').hide();
		            $('#communityTrap').hide();
		        }
		    }
		    $('#snmp').validate({
		        rules: {
		            snmptraps_intervall: {
		                required: true,
		                digits: true,
		            },
		            snmp_community_ro: {
		                checkSnmp: true
		            },
		            snmp_community_rw: {
		                checkSnmp: true
		            },
		            snmp_community_trap: {
		                checkSnmp: true
		            },
		        }
		    });
		</script>
		<?php
		return ob_get_clean();
	}

	/**
	 * Generates the html form for the SNMP settings
	 * @return string HTML form
	 */
	function snmpTable() {
		ob_start();
		?>
		<form id='snmp' action='' method='POST' class="form-horizontal">
			<input type=hidden name=m value="<?php echo $this->m_attr ?>">
			<div class="form-group">
				<label for='snmp_enabled' class='col-sm-5 control-label'><?php echo SNMP_ENABLED_DIS ?></label>
				<div class='col-sm-4 form-checkbox'>
					<?php echo $this->snmp_enabled() ?>
				</div>
			</div>
			<div class="form-group" id='snmp_syslocation'>
				<label for='snmp_syslocation' class='col-sm-5 control-label'><?php echo SNMP_SYSLOCATION ?></label>
				<div class='col-sm-4'>
					<?php echo $this->snmp_syslocation() ?>
				</div>
			</div>
			<div class="form-group" id='traps'>
				<label for='snmptraps' class='col-sm-5 control-label'><?php echo SNMP_TRAPS_DIS ?></label>
				<div class='col-sm-4 form-checkbox'>
					<?php echo $this->snmptraps() ?>
				</div>
			</div>
			<div class="form-group" id='sink'>
				<label for='snmptraps_sink' class='col-sm-5 control-label'><?php echo SNMP_TRAPS_SINK_DIS ?></label>
				<div class='col-sm-4'>
					<?php echo $this->snmptraps_sink() ?>
				</div>
			</div>
			<div class="form-group" id='interval'>
				<label for='snmptraps_intervall' class='col-sm-5 control-label'><?php echo SNMP_TRAPS_INTERVALL_DIS ?></label>
				<div class='col-sm-4'>
					<?php echo $this->snmptraps_intervall() ?>
				</div>
			</div>
			<div class="form-group" id='communityRo'>
				<label for='snmp_community_ro' class='col-sm-5 control-label'><?php echo SNMP_RO_COMMUNITY_DIS ?></label>
				<div class='col-sm-4'>
					<?php echo $this->ro_community() ?>
				</div>
			</div>
			<div class="form-group" id='communityRw'>
				<label for='snmp_community_rw' class='col-sm-5 control-label'><?php echo SNMP_RW_COMMUNITY_DIS ?></label>
				<div class='col-sm-4'>
					<?php echo $this->rw_community() ?>
				</div>
			</div>
			<div class="form-group" id='communityTrap'>
				<label for='snmp_community_trap' class='col-sm-5 control-label'><?php echo SNMP_COMMUNITY_TRAP_DIS ?></label>
				<div class='col-sm-4'>
					<?php echo $this->community_trap() ?>
				</div>
			</div>
			<?php if (is_file("/usr/local/conf/BEROFIX-MIB.txt")): ?>
				<div class="text-center" >
					<a href="misc/files_download.php?option=BEROFIX-MIB">Download BEROFIX-MIB</a>
				</div>
			<?php endif; ?>
			<br>			
			<div class="text-center" >
				<input name='submit' class='btn btn-default' type='submit' value='<?php echo BUTTON_SAVE ?>'>
			</div>
		</form>
		<?php
		return ob_get_clean();
	}

	/**
	 * Saves the setting in the database
	 * @param beroAri $ba
	 * @return string HTML code
	 */
	function save($ba) {
		require_once( '/usr/fallback/beroConf.php' );
		$bc = new beroConf('root');
	
		if (isset($this->post_attr['snmp_enabled'])) {
			$bc->set('root', 'snmp-enabled', $this->post_attr['snmp_enabled']);
			if ($this->post_attr['snmp_enabled'] == 1) {
				$bc->set('root', 'snmptraps', sqlite_escape_string($this->post_attr['snmptraps']));
				$bc->set('root', 'snmp-syslocation', sqlite_escape_string($this->post_attr['snmp_syslocation']));
				$bc->set('root', 'snmptraps_sink', sqlite_escape_string($this->post_attr['snmptraps_sink']));
				$bc->set('root', 'snmptraps_intervall', sqlite_escape_string($this->post_attr['snmptraps_intervall']));
				$bc->set('root', 'snmp-community-rw', sqlite_escape_string($this->post_attr['snmp_community_rw']));
				$bc->set('root', 'snmp-community-ro', sqlite_escape_string($this->post_attr['snmp_community_ro']));
				$bc->set('root', 'snmp-community-trap', sqlite_escape_string($this->post_attr['snmp_community_trap']));
			} else {
				$bc->set('root', 'snmptraps', "");
				$bc->set('root', 'snmp-syslocation', '');
				$bc->set('root', 'snmptraps_sink', "");
				$bc->set('root', 'snmptraps_intervall', "");
				$bc->set('root', 'snmp-community-rw', "");
				$bc->set('root', 'snmp-community-ro', "");
				$bc->set('root', 'snmp-community-trap', "");
			}

			$table .= Helper::activate(2, true, $this->m_attr, ACTIVATE);
			return $table;
		}
		
		return $table;
	}
}
?>
